@@ -4,7 +4,7 @@ from __future__ import annotations
 import json
 import os
 import sys
-from typing import Any, Dict, List, Tuple, TYPE_CHECKING
+from typing import Any, Dict, List, Tuple, TYPE_CHECKING, Union
 from urllib.parse import urlsplit, urlparse
 
 import grpc
@@ -102,7 +102,7 @@ def send_alert(run_id: int, team_name: str, exp_name: str, alert_msg: str):
 
     return rsp.rsp_result.result == "success"
 
-def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
+def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Union[int, str, float, bool]]) -> bool:
     item_list = []
 
     def makeItem(item):
@@ -118,7 +118,8 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Any]) -> bool:
             logItem = LogItem(key=key, valueAsFloat=value)
         elif isinstance(value, bool):
             logItem = LogItem(key=key, valueAsBool=value)
-
+        else:
+            raise Exception("value는 int, str, float, bool 타입만 가능합니다.")
         return logItem
 
     item = map(makeItem, item_dict.items())
